@@ -78,6 +78,9 @@ pref("calendar.itip.displayInvitationChanges", true);
 //whether for delegated invitations a delegatee's replies will be send also to delegator(s)
 pref("calendar.itip.notifyDelegatorOnReply", true);
 
+// whether to prefix the subject field for email invitation invites or updates.
+pref("calendar.itip.useInvitationSubjectPrefixes", true);
+
 // whether CalDAV (experimental) scheduling is enabled or not.
 pref("calendar.caldav.sched.enabled", false);
 
@@ -138,19 +141,28 @@ pref("calendar.threading.latency ", 250);
 pref("calendar.network.multirealm", false);
 
 // Set up user agent
-pref("calendar.useragent.extra", "Lightning/4.7.2");
+pref("calendar.useragent.extra", "Lightning/5.4");
 
 // Disable use of system colors in minimonth and calendar views
 pref("calendar.view.useSystemColors", false);
 
+// Disable hiding the label on todayPane button
+pref("calendar.view.showTodayPaneStatusLabel", true);
+
 // Maximum number of iterations allowed when searching for the next matching
 // occurrence of a repeating item in calFilter
 pref("calendar.filter.maxiterations", 50);
 
+// Edit events and tasks in a tab rather than a window.
+pref("calendar.item.editInTab", false);
+
+// Edit events and tasks in the new (HTML-based) UI for tabs and windows
+pref("calendar.item.useNewItemUI", false);
+
 // Backend to use. false: libical, true: ical.js
-//@line 154 "/builds/slave/tb-c-esr45-l64-ntly-0000000000/build/calendar/lightning/content/lightning.js"
+//@line 166 "/builds/slave/tb-c-esr52-l64-ntly-0000000000/build/calendar/lightning/content/lightning.js"
 pref("calendar.icaljs", false);
-//@line 156 "/builds/slave/tb-c-esr45-l64-ntly-0000000000/build/calendar/lightning/content/lightning.js"
+//@line 168 "/builds/slave/tb-c-esr52-l64-ntly-0000000000/build/calendar/lightning/content/lightning.js"
 
 // Calendar integration notification
 pref("calendar.integration.notify", true);
